# UpsRating Python SDK 1.0.0

Welcome to the UpsRating SDK documentation. This guide will help you get started with integrating and using the UpsRating SDK in your project.

## Versions

- SDK version: `1.0.0`

## About the API

Compare delivery services and shipping rates to determine the best option. In order to obtain your bearer token please follow the instructions at https://developer.ups.com/get-started, or use the UPS Authorization API.

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [Access Token Authentication](#access-token-authentication)
- [Services](#services)
- [Models](#models)
- [License](#license)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install ups-rating
```

## Authentication

### Access Token Authentication

The UpsRating API uses an Access Token for authentication.

This token must be provided to authenticate your requests to the API.

#### Setting the Access Token

When you initialize the SDK, you can set the access token as follows:

```py
UpsRating(
    access_token="YOUR_ACCESS_TOKEN"
)
```

If you need to set or update the access token after initializing the SDK, you can use:

```py
sdk.set_access_token("YOUR_ACCESS_TOKEN")
```

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                                           |
| :----------------------------------------------------------------------------- |
| [VersionService](documentation/services/VersionService.md)                     |
| [DeprecatedVersionService](documentation/services/DeprecatedVersionService.md) |

</details>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                                                   | Description                                                                                                                                                                                                                                                                                                                                |
| :--------------------------------------------------------------------------------------------------------------------- | :----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [RateRequestWrapper](documentation/models/RateRequestWrapper.md)                                                       | N/A                                                                                                                                                                                                                                                                                                                                        |
| [RateResponseWrapper](documentation/models/RateResponseWrapper.md)                                                     | N/A                                                                                                                                                                                                                                                                                                                                        |
| [RateRequest](documentation/models/RateRequest.md)                                                                     | Rate Request container.                                                                                                                                                                                                                                                                                                                    |
| [RateRequestRequest](documentation/models/RateRequestRequest.md)                                                       | Request container. N/A                                                                                                                                                                                                                                                                                                                     |
| [RateRequestPickupType](documentation/models/RateRequestPickupType.md)                                                 | Pickup Type container tag.                                                                                                                                                                                                                                                                                                                 |
| [RateRequestCustomerClassification](documentation/models/RateRequestCustomerClassification.md)                         | Customer classification container. Valid if ShipFrom country or territory is "US"                                                                                                                                                                                                                                                          |
| [RateRequestShipment](documentation/models/RateRequestShipment.md)                                                     | Container for Shipment Information.                                                                                                                                                                                                                                                                                                        |
| [RequestTransactionReference](documentation/models/RequestTransactionReference.md)                                     | TransactionReference identifies transactions between client and server.                                                                                                                                                                                                                                                                    |
| [ShipmentShipper](documentation/models/ShipmentShipper.md)                                                             | Shipper container. Information associated with the UPS account number.                                                                                                                                                                                                                                                                     |
| [ShipmentShipTo](documentation/models/ShipmentShipTo.md)                                                               | Ship To Container                                                                                                                                                                                                                                                                                                                          |
| [ShipmentShipFrom](documentation/models/ShipmentShipFrom.md)                                                           | Ship From Container.                                                                                                                                                                                                                                                                                                                       |
| [ShipmentAlternateDeliveryAddress](documentation/models/ShipmentAlternateDeliveryAddress.md)                           | Alternate Delivery Address container. Applies for deliveries to UPS Access Point™ locations. Required for the following ShipmentIndicationType values: - 01 - Hold for Pickup at UPS Access Point™ - 02 - UPS Access Point™ Delivery                                                                                                    |
| [ShipmentShipmentIndicationType](documentation/models/ShipmentShipmentIndicationType.md)                               | Container to hold shipment indication type.                                                                                                                                                                                                                                                                                                |
| [ShipmentPaymentDetails](documentation/models/ShipmentPaymentDetails.md)                                               | Payment details container for detailed shipment charges. The two shipment charges that are available for specification are Transportation charges and Duties and Taxes. This container is used for Who Pays What functionality.                                                                                                            |
| [ShipmentFrsPaymentInformation](documentation/models/ShipmentFrsPaymentInformation.md)                                 | UPS Ground Freight Pricing (GFP) Payment Information container. Required only for GFP and when the FRSIndicator is present.                                                                                                                                                                                                                |
| [ShipmentFreightShipmentInformation](documentation/models/ShipmentFreightShipmentInformation.md)                       | Container to hold Freight Shipment information.                                                                                                                                                                                                                                                                                            |
| [ShipmentService](documentation/models/ShipmentService.md)                                                             | Service Container. Only valid with RequestOption = Rate for both Small package and GFP Rating requests.                                                                                                                                                                                                                                    |
| [ShipmentShipmentTotalWeight](documentation/models/ShipmentShipmentTotalWeight.md)                                     | Shipment Total Weight Container. This container is only applicable for "ratetimeintransit" and "shoptimeintransit" request options. Required for all international shipments when retreiving time in transit information, including letters and documents shipments.                                                                       |
| [ShipmentPackage](documentation/models/ShipmentPackage.md)                                                             | Package Container. Only one Package allowed for Simple Rate                                                                                                                                                                                                                                                                                |
| [ShipmentShipmentServiceOptions](documentation/models/ShipmentShipmentServiceOptions.md)                               | Shipment level Accessorials are included in this container.                                                                                                                                                                                                                                                                                |
| [ShipmentShipmentRatingOptions](documentation/models/ShipmentShipmentRatingOptions.md)                                 | Shipment Rating Options container.                                                                                                                                                                                                                                                                                                         |
| [ShipmentInvoiceLineTotal](documentation/models/ShipmentInvoiceLineTotal.md)                                           | Container to hold InvoiceLineTotal Information. Required if the shipment is from US/PR Outbound to non US/PR destination with the PackagingType of UPS PAK(04).Required for international shipments when using request option "ratetimeintransit" or "shoptimeintransit".                                                                  |
| [ShipmentPromotionalDiscountInformation](documentation/models/ShipmentPromotionalDiscountInformation.md)               | PromotionalDiscountInformation container. This container contains discount information that the customer wants to request each time while placing a shipment.                                                                                                                                                                              |
| [ShipmentDeliveryTimeInformation](documentation/models/ShipmentDeliveryTimeInformation.md)                             | Container for requesting Time In Transit Information. Required to view time in transit information. Required to view any time in transit information.                                                                                                                                                                                      |
| [ShipperAddress](documentation/models/ShipperAddress.md)                                                               | Address Container. If the ShipFrom container is not present then this address will be used as the ShipFrom. If this address is used as the ShipFrom, the shipment will be rated from this origin address.                                                                                                                                  |
| [ShipToAddress](documentation/models/ShipToAddress.md)                                                                 | Address Container.                                                                                                                                                                                                                                                                                                                         |
| [ShipFromAddress](documentation/models/ShipFromAddress.md)                                                             | Address container for Ship From. Address Container                                                                                                                                                                                                                                                                                         |
| [AlternateDeliveryAddressAddress](documentation/models/AlternateDeliveryAddressAddress.md)                             | Address container for Alternate Delivery Address.                                                                                                                                                                                                                                                                                          |
| [PaymentDetailsShipmentCharge](documentation/models/PaymentDetailsShipmentCharge.md)                                   | Shipment charge container. If Duty and Tax charges are applicable to a shipment and a payer is not specified, the default payer of Duty and Tax charges is Bill to Receiver. There will be no default payer of Duty and Tax charges for DDU and DDP service.                                                                               |
| [ShipmentChargeBillShipper](documentation/models/ShipmentChargeBillShipper.md)                                         | Container for the BillShipper billing option. This element or its sibling element, BillReceiver, BillThirdParty or ConsigneeBilledIndicator, must be present but no more than one can be present.                                                                                                                                          |
| [ShipmentChargeBillReceiver](documentation/models/ShipmentChargeBillReceiver.md)                                       | Container for the BillReceiver billing option. This element or its sibling element, BillShipper, BillThirdParty or Consignee Billed, must be present but no more than one can be present. For a return shipment, Bill Receiver is invalid for Transportation charges.                                                                      |
| [ShipmentChargeBillThirdParty](documentation/models/ShipmentChargeBillThirdParty.md)                                   | Container for the third party billing option. This element or its sibling element, BillShipper, BillReceiver or Consignee Billed, must be present but no more than one can be present.                                                                                                                                                     |
| [BillReceiverAddress](documentation/models/BillReceiverAddress.md)                                                     | Container for additional information for the bill receiver's UPS accounts address.                                                                                                                                                                                                                                                         |
| [BillThirdPartyAddress](documentation/models/BillThirdPartyAddress.md)                                                 | Container for additional information for the third party UPS accounts address.                                                                                                                                                                                                                                                             |
| [FrsPaymentInformationType](documentation/models/FrsPaymentInformationType.md)                                         | GFP Payment Information Type container. GFP only.                                                                                                                                                                                                                                                                                          |
| [FrsPaymentInformationAddress](documentation/models/FrsPaymentInformationAddress.md)                                   | Payer Address Container. Address container may be present for FRS Payment Information type = 02 and required when the FRS Payment Information type = 03.                                                                                                                                                                                   |
| [FreightShipmentInformationFreightDensityInfo](documentation/models/FreightShipmentInformationFreightDensityInfo.md)   | Freight Density Info container. Required if DensityEligibleIndicator is present.                                                                                                                                                                                                                                                           |
| [FreightDensityInfoAdjustedHeight](documentation/models/FreightDensityInfoAdjustedHeight.md)                           | Container to hold Adjusted Height information. Required if AdjustedHeightIndicator is present.                                                                                                                                                                                                                                             |
| [FreightDensityInfoHandlingUnits](documentation/models/FreightDensityInfoHandlingUnits.md)                             | Handling Unit for Density based rating container.                                                                                                                                                                                                                                                                                          |
| [AdjustedHeightUnitOfMeasurement](documentation/models/AdjustedHeightUnitOfMeasurement.md)                             | Unit of Measurement container for the Adjusted height.                                                                                                                                                                                                                                                                                     |
| [HandlingUnitsType](documentation/models/HandlingUnitsType.md)                                                         | Handling Unit Type for Density based rating.                                                                                                                                                                                                                                                                                               |
| [HandlingUnitsDimensions](documentation/models/HandlingUnitsDimensions.md)                                             | Dimension of the HandlingUnit container for density based pricing.                                                                                                                                                                                                                                                                         |
| [HandlingUnitsUnitOfMeasurement](documentation/models/HandlingUnitsUnitOfMeasurement.md)                               | UnitOfMeasurement container.                                                                                                                                                                                                                                                                                                               |
| [ShipmentTotalWeightUnitOfMeasurement](documentation/models/ShipmentTotalWeightUnitOfMeasurement.md)                   | UnitOfMeasurement Container.                                                                                                                                                                                                                                                                                                               |
| [PackagePackagingType](documentation/models/PackagePackagingType.md)                                                   | Packaging Type Container.                                                                                                                                                                                                                                                                                                                  |
| [PackageDimensions](documentation/models/PackageDimensions.md)                                                         | Dimensions Container. This container is not applicable for GFP Rating request. Required for Heavy Goods service. Package Dimension will be ignored for Simple Rate                                                                                                                                                                         |
| [PackageDimWeight](documentation/models/PackageDimWeight.md)                                                           | Package Dimensional Weight container. Values in this container are ignored when package dimensions are provided. Please visit ups.com for instructions on calculating this value. Only used for non-US/CA/PR shipments.                                                                                                                    |
| [PackagePackageWeight](documentation/models/PackagePackageWeight.md)                                                   | Package Weight Container. Required for an GFP Rating request. Otherwise optional. Required for Heavy Goods service. Package Weight will be ignored for Simple Rate                                                                                                                                                                         |
| [PackageCommodity](documentation/models/PackageCommodity.md)                                                           | Commodity Container. Required only for GFP rating when FRSShipmentIndicator is requested.                                                                                                                                                                                                                                                  |
| [PackagePackageServiceOptions](documentation/models/PackagePackageServiceOptions.md)                                   | PackageServiceOptions container.                                                                                                                                                                                                                                                                                                           |
| [PackageSimpleRate](documentation/models/PackageSimpleRate.md)                                                         | SimpleRate Container                                                                                                                                                                                                                                                                                                                       |
| [PackageUpsPremier](documentation/models/PackageUpsPremier.md)                                                         | UPS Premier                                                                                                                                                                                                                                                                                                                                |
| [DimensionsUnitOfMeasurement](documentation/models/DimensionsUnitOfMeasurement.md)                                     | UnitOfMeasurement container.                                                                                                                                                                                                                                                                                                               |
| [DimWeightUnitOfMeasurement](documentation/models/DimWeightUnitOfMeasurement.md)                                       | UnitOfMeasurement Container.                                                                                                                                                                                                                                                                                                               |
| [PackageWeightUnitOfMeasurement](documentation/models/PackageWeightUnitOfMeasurement.md)                               | UnitOfMeasurement Container.                                                                                                                                                                                                                                                                                                               |
| [CommodityNmfc](documentation/models/CommodityNmfc.md)                                                                 | NMFC Commodity container. For GFP Only.                                                                                                                                                                                                                                                                                                    |
| [PackageServiceOptionsDeliveryConfirmation](documentation/models/PackageServiceOptionsDeliveryConfirmation.md)         | Delivery Confirmation Container. For a list of valid origin/destination countries or territories please refer to appendix. DeliveryConfirmation and COD are mutually exclusive.                                                                                                                                                            |
| [PackageServiceOptionsAccessPointCod](documentation/models/PackageServiceOptionsAccessPointCod.md)                     | Access Point COD indicates Package COD is requested for a shipment. Valid only for : 01 - Hold For Pickup At UPS Access Point, Shipment Indication type. Package Access Point COD is valid only for shipment without return service from US/PR to US/PR and CA to CA. Not valid with (Package) COD.                                        |
| [PackageServiceOptionsCod](documentation/models/PackageServiceOptionsCod.md)                                           | COD Container. Indicates COD is requested. Valid for the following country or territory combinations: US/PR to US/PRCA to CACA to USNot allowed for CA to US for packages that are designated as Letters or Envelopes.                                                                                                                     |
| [PackageServiceOptionsDeclaredValue](documentation/models/PackageServiceOptionsDeclaredValue.md)                       | Declared Value Container.                                                                                                                                                                                                                                                                                                                  |
| [PackageServiceOptionsShipperDeclaredValue](documentation/models/PackageServiceOptionsShipperDeclaredValue.md)         | Shipper Paid Declared Value Charge at Package level. Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                                                   |
| [PackageServiceOptionsInsurance](documentation/models/PackageServiceOptionsInsurance.md)                               | Insurance Accesorial. Only one type of insurance can exist at a time on the shipment. Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                  |
| [PackageServiceOptionsHazMat](documentation/models/PackageServiceOptionsHazMat.md)                                     | Container to hold HazMat information. Applies only if SubVersion is greater than or equal to 1701.                                                                                                                                                                                                                                         |
| [PackageServiceOptionsDryIce](documentation/models/PackageServiceOptionsDryIce.md)                                     | Container to hold Dry Ice information. Lane check will happen based on postal code/ city.                                                                                                                                                                                                                                                  |
| [CodCodAmount](documentation/models/CodCodAmount.md)                                                                   | CODAmount Container.                                                                                                                                                                                                                                                                                                                       |
| [InsuranceBasicFlexibleParcelIndicator](documentation/models/InsuranceBasicFlexibleParcelIndicator.md)                 | Container to hold Basic Flexible Parcel Indicator information. Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                                         |
| [InsuranceExtendedFlexibleParcelIndicator](documentation/models/InsuranceExtendedFlexibleParcelIndicator.md)           | Container for Extended Flexible Parcel Indicator Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                                                       |
| [InsuranceTimeInTransitFlexibleParcelIndicator](documentation/models/InsuranceTimeInTransitFlexibleParcelIndicator.md) | Container to hold Time In Transit Flexible Parcel Indicator information. Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                               |
| [HazMatHazMatChemicalRecord](documentation/models/HazMatHazMatChemicalRecord.md)                                       | Container to hold HazMat Chemical Records.                                                                                                                                                                                                                                                                                                 |
| [DryIceDryIceWeight](documentation/models/DryIceDryIceWeight.md)                                                       | Container for Weight information for Dry Ice.                                                                                                                                                                                                                                                                                              |
| [DryIceWeightUnitOfMeasurement](documentation/models/DryIceWeightUnitOfMeasurement.md)                                 | Container for Unit Of Measurement for Dry Ice.                                                                                                                                                                                                                                                                                             |
| [ShipmentServiceOptionsAccessPointCod](documentation/models/ShipmentServiceOptionsAccessPointCod.md)                   | Access Point COD indicates Shipment level Access Point COD is requested for a shipment. Valid only for "01 - Hold For Pickup At UPS Access Point" Shipment Indication type. Shipment Access Point COD is valid only for countries or territories within E.U. Not valid with (Shipment) COD. Not available to shipment with return service. |
| [ShipmentServiceOptionsCod](documentation/models/ShipmentServiceOptionsCod.md)                                         | If present, indicates C.O.D. is requested for the shipment. Shipment level C.O.D. is only available for EU origin countries or territories.C.O.D. shipments are only available for Shippers with Daily Pickup and Drop Shipping accounts.                                                                                                  |
| [ShipmentServiceOptionsDeliveryConfirmation](documentation/models/ShipmentServiceOptionsDeliveryConfirmation.md)       | Delivery Confirmation Container. DeliveryConfirmation and C.O.D. are mutually exclusive. Refer to the Appendix for a list of valid origin-destination country or territory pairs associated with each confirmation type.                                                                                                                   |
| [ShipmentServiceOptionsPickupOptions](documentation/models/ShipmentServiceOptionsPickupOptions.md)                     | Shipment Service Pickup Options Container. Valid for UPS Worldwide Express Freight and UPS Worldwide Express Freight Midday shipments.                                                                                                                                                                                                     |
| [ShipmentServiceOptionsDeliveryOptions](documentation/models/ShipmentServiceOptionsDeliveryOptions.md)                 | Shipment Service Delivery Options Container. Valid for UPS Worldwide Express Freight and UPS Worldwide Express Freight Midday shipments.                                                                                                                                                                                                   |
| [ShipmentServiceOptionsRestrictedArticles](documentation/models/ShipmentServiceOptionsRestrictedArticles.md)           | Restricted Articles container. Valid for UPS World Wide Express Freight shipments.                                                                                                                                                                                                                                                         |
| [ShipmentServiceOptionsImportControl](documentation/models/ShipmentServiceOptionsImportControl.md)                     | Container for type of Import Control shipments.                                                                                                                                                                                                                                                                                            |
| [ShipmentServiceOptionsReturnService](documentation/models/ShipmentServiceOptionsReturnService.md)                     | Container for type of Return Services.                                                                                                                                                                                                                                                                                                     |
| [ShipmentServiceOptionsCodCodAmount](documentation/models/ShipmentServiceOptionsCodCodAmount.md)                       | CODAmount Container. UPS does not support all international currency codes. Refer to the appendix for a list of valid codes.                                                                                                                                                                                                               |
| [DeliveryTimeInformationPickup](documentation/models/DeliveryTimeInformationPickup.md)                                 | Pickup container.                                                                                                                                                                                                                                                                                                                          |
| [DeliveryTimeInformationReturnContractServices](documentation/models/DeliveryTimeInformationReturnContractServices.md) | Return contract services container                                                                                                                                                                                                                                                                                                         |
| [RateResponse](documentation/models/RateResponse.md)                                                                   | Rate Response Container.                                                                                                                                                                                                                                                                                                                   |
| [RateResponseResponse](documentation/models/RateResponseResponse.md)                                                   | Response Container.                                                                                                                                                                                                                                                                                                                        |
| [RateResponseRatedShipment](documentation/models/RateResponseRatedShipment.md)                                         |                                                                                                                                                                                                                                                                                                                                            |
| [ResponseResponseStatus](documentation/models/ResponseResponseStatus.md)                                               | Response Status Container.                                                                                                                                                                                                                                                                                                                 |
| [ResponseAlert](documentation/models/ResponseAlert.md)                                                                 | Alert container. There can be zero to many alert containers with code and description.                                                                                                                                                                                                                                                     |
| [ResponseAlertDetail](documentation/models/ResponseAlertDetail.md)                                                     |                                                                                                                                                                                                                                                                                                                                            |
| [ResponseTransactionReference](documentation/models/ResponseTransactionReference.md)                                   | Transaction Reference Container.                                                                                                                                                                                                                                                                                                           |
| [AlertDetailElementLevelInformation](documentation/models/AlertDetailElementLevelInformation.md)                       | Provides more information about the element that represents the alert.                                                                                                                                                                                                                                                                     |
| [ElementLevelInformationElementIdentifier](documentation/models/ElementLevelInformationElementIdentifier.md)           |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentDisclaimer](documentation/models/RatedShipmentDisclaimer.md)                                             |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentService](documentation/models/RatedShipmentService.md)                                                   | Service Container.                                                                                                                                                                                                                                                                                                                         |
| [RatedShipmentRatedShipmentAlert](documentation/models/RatedShipmentRatedShipmentAlert.md)                             |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentBillingWeight](documentation/models/RatedShipmentBillingWeight.md)                                       | Billing Weight Container.                                                                                                                                                                                                                                                                                                                  |
| [RatedShipmentTransportationCharges](documentation/models/RatedShipmentTransportationCharges.md)                       | Transportation Charges Container.                                                                                                                                                                                                                                                                                                          |
| [RatedShipmentBaseServiceCharge](documentation/models/RatedShipmentBaseServiceCharge.md)                               | Base Service Charge Container. These charges would be returned only when subversion is greater than or equal to 1701                                                                                                                                                                                                                       |
| [RatedShipmentItemizedCharges](documentation/models/RatedShipmentItemizedCharges.md)                                   |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentFrsShipmentData](documentation/models/RatedShipmentFrsShipmentData.md)                                   | FRSShipmentData container. Only returned when the FRSShipmentIIndicator is used. UPS Ground Freight Pricing Only.                                                                                                                                                                                                                          |
| [RatedShipmentServiceOptionsCharges](documentation/models/RatedShipmentServiceOptionsCharges.md)                       | Service Options Charges Container.                                                                                                                                                                                                                                                                                                         |
| [RatedShipmentTaxCharges](documentation/models/RatedShipmentTaxCharges.md)                                             |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentTotalCharges](documentation/models/RatedShipmentTotalCharges.md)                                         | Total Charges Container.                                                                                                                                                                                                                                                                                                                   |
| [RatedShipmentTotalChargesWithTaxes](documentation/models/RatedShipmentTotalChargesWithTaxes.md)                       | TotalChargesWithTaxes container would be returned only if TaxInformationIndicator is present in request and when Negotiated Rates are not applicable. TotalChargesWithTaxes contains total charges including total taxes applied to a shipment.                                                                                            |
| [RatedShipmentNegotiatedRateCharges](documentation/models/RatedShipmentNegotiatedRateCharges.md)                       | Negotiated Rate Charges Container. For tiered rates and promotional discounts, if a particular shipment based on zone, origin, destination or even shipment size doesn't qualify for the existing discount then no negotiated rates container will be returned. Published rates will be the applicable rate.                               |
| [RatedShipmentRatedPackage](documentation/models/RatedShipmentRatedPackage.md)                                         |                                                                                                                                                                                                                                                                                                                                            |
| [RatedShipmentTimeInTransit](documentation/models/RatedShipmentTimeInTransit.md)                                       | Container for returned Time in Transit information. Will only be returned if request option was either "ratetimeintransit" or "shoptimeintransit" and DeliveryTimeInformation container was present in request.                                                                                                                            |
| [BillingWeightUnitOfMeasurement](documentation/models/BillingWeightUnitOfMeasurement.md)                               | Unit Of Measurement Container.                                                                                                                                                                                                                                                                                                             |
| [FrsShipmentDataTransportationCharges](documentation/models/FrsShipmentDataTransportationCharges.md)                   | Transportation Charges Container                                                                                                                                                                                                                                                                                                           |
| [FrsShipmentDataFreightDensityRate](documentation/models/FrsShipmentDataFreightDensityRate.md)                         | FreightDensityRate container for Density based rating.                                                                                                                                                                                                                                                                                     |
| [FrsShipmentDataHandlingUnits](documentation/models/FrsShipmentDataHandlingUnits.md)                                   |                                                                                                                                                                                                                                                                                                                                            |
| [TransportationChargesGrossCharge](documentation/models/TransportationChargesGrossCharge.md)                           | Gross Transportation Charges Container                                                                                                                                                                                                                                                                                                     |
| [TransportationChargesDiscountAmount](documentation/models/TransportationChargesDiscountAmount.md)                     | Discount Container                                                                                                                                                                                                                                                                                                                         |
| [TransportationChargesNetCharge](documentation/models/TransportationChargesNetCharge.md)                               | Net Transportation Rate Container                                                                                                                                                                                                                                                                                                          |
| [HandlingUnitsAdjustedHeight](documentation/models/HandlingUnitsAdjustedHeight.md)                                     | Container to hold Adjusted Height information.                                                                                                                                                                                                                                                                                             |
| [NegotiatedRateChargesItemizedCharges](documentation/models/NegotiatedRateChargesItemizedCharges.md)                   |                                                                                                                                                                                                                                                                                                                                            |
| [NegotiatedRateChargesTaxCharges](documentation/models/NegotiatedRateChargesTaxCharges.md)                             |                                                                                                                                                                                                                                                                                                                                            |
| [NegotiatedRateChargesTotalCharge](documentation/models/NegotiatedRateChargesTotalCharge.md)                           | Total Charges Container.                                                                                                                                                                                                                                                                                                                   |
| [NegotiatedRateChargesTotalChargesWithTaxes](documentation/models/NegotiatedRateChargesTotalChargesWithTaxes.md)       | TotalChargesWithTaxes container would be returned only if TaxInformationIndicator is present in request. TotalChargesWithTaxes contains total charges including total taxes applied to a shipment.                                                                                                                                         |
| [RatedPackageBaseServiceCharge](documentation/models/RatedPackageBaseServiceCharge.md)                                 | Base Service Charge Container. These charges would be returned only when subversion is greater than or equal to 1701                                                                                                                                                                                                                       |
| [RatedPackageTransportationCharges](documentation/models/RatedPackageTransportationCharges.md)                         | Transportation Charges Container.                                                                                                                                                                                                                                                                                                          |
| [RatedPackageServiceOptionsCharges](documentation/models/RatedPackageServiceOptionsCharges.md)                         | Service Options Charges Container.                                                                                                                                                                                                                                                                                                         |
| [RatedPackageTotalCharges](documentation/models/RatedPackageTotalCharges.md)                                           | Total Charges Container.                                                                                                                                                                                                                                                                                                                   |
| [RatedPackageBillingWeight](documentation/models/RatedPackageBillingWeight.md)                                         | Billing Weight Container.                                                                                                                                                                                                                                                                                                                  |
| [RatedPackageAccessorial](documentation/models/RatedPackageAccessorial.md)                                             |                                                                                                                                                                                                                                                                                                                                            |
| [RatedPackageItemizedCharges](documentation/models/RatedPackageItemizedCharges.md)                                     |                                                                                                                                                                                                                                                                                                                                            |
| [RatedPackageNegotiatedCharges](documentation/models/RatedPackageNegotiatedCharges.md)                                 | Negotiated Rates container. These charges would be returned only when -1) subversion is greater than or equal to 16072) if negotiated rates were requested for GFP shipments and account number is eligible to receive negotiated rates.                                                                                                   |
| [RatedPackageSimpleRate](documentation/models/RatedPackageSimpleRate.md)                                               | SimpleRate will be returned if Simple Rate present in request                                                                                                                                                                                                                                                                              |
| [RatedPackageRateModifier](documentation/models/RatedPackageRateModifier.md)                                           |                                                                                                                                                                                                                                                                                                                                            |
| [RatedPackageBillingWeightUnitOfMeasurement](documentation/models/RatedPackageBillingWeightUnitOfMeasurement.md)       | Unit Of Measurement Container.                                                                                                                                                                                                                                                                                                             |
| [NegotiatedChargesItemizedCharges](documentation/models/NegotiatedChargesItemizedCharges.md)                           |                                                                                                                                                                                                                                                                                                                                            |
| [TimeInTransitServiceSummary](documentation/models/TimeInTransitServiceSummary.md)                                     | Container for all available service information.                                                                                                                                                                                                                                                                                           |
| [ServiceSummaryService](documentation/models/ServiceSummaryService.md)                                                 | Container for the the UPS service selected for a shipment.                                                                                                                                                                                                                                                                                 |
| [ServiceSummaryEstimatedArrival](documentation/models/ServiceSummaryEstimatedArrival.md)                               | Container for the Time-In-Transit arrival information by service                                                                                                                                                                                                                                                                           |
| [EstimatedArrivalArrival](documentation/models/EstimatedArrivalArrival.md)                                             | Container for the Time-In-Transit arrival information by service. This is the most accurate delivery information available via the Rating API and will reflect changes in delivery schedules due to peak business seasons or holidays.                                                                                                     |
| [EstimatedArrivalPickup](documentation/models/EstimatedArrivalPickup.md)                                               | The date and pick up time container.                                                                                                                                                                                                                                                                                                       |

</details>

## License

This SDK is licensed under the MIT License.

See the [LICENSE](LICENSE) file for more details.

<!-- This file was generated by liblab | https://liblab.com/ -->
